==> upstartr_0.1.0.tar.gz: upstartr/README.md <==
# upstartr

<!-- badges: start -->
[![R build status](https://github.com/globeandmail/upstartr/workflows/R-CMD-check/badge.svg)](https://github.com/globeandmail/upstartr/actions)
[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/upstartr)](https://cran.r-project.org/package=upstartr)
[![CRAN_Downloads_Badge](https://cranlogs.r-pkg.org/badges/upstartr)](https://cranlogs.r-pkg.org/badges/upstartr)
<!-- badges: end -->
<p align="center">
  <img src="https://raw.githubusercontent.com/globeandmail/upstartr/master/images/upstartr-sticker.png" alt="upstartr logo" width="40%" height="40%" />
</p>

Upstartr is a companion package to The Globe and Mail's data journalism template, [**startr**](https://github.com/globeandmail/startr). It contains a series of functions meant to be consumed by the template project, plus additional helpful functions for day-to-day data journalism.

### Installation

```r
install.packages('upstartr')
```

Or, if you want to run a development version, you can install it from GitHub by doing:
```r
devtools::install_github('globeandmail/upstartr')
library(upstartr)
```

### Reference

You can find the full reference manual for `upstartr`'s functions [**here**](https://globeandmail.github.io/upstartr/).

### Credits

Spark plug illustration by Murat Yükselir.

### Get in touch

If you've got any questions, feel free to send us an email, or give us a shout on Twitter:

[![Tom Cardoso](https://avatars0.githubusercontent.com/u/2408118?v=3&s=65)](https://github.com/tomcardoso)
---
[Tom Cardoso](mailto:tcardoso@globeandmail.com) <br> [@tom_cardoso](https://www.twitter.com/tom_cardoso)

==> upstartr_0.1.2.tar.gz: upstartr/README.md <==
# upstartr

<!-- badges: start -->
[![R-CMD-check](https://github.com/globeandmail/upstartr/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/globeandmail/upstartr/actions/workflows/R-CMD-check.yaml)
[![CRAN_Status_Badge](http://www.r-pkg.org/badges/version/upstartr)](https://cran.r-project.org/package=upstartr)
[![CRAN_Downloads_Badge](https://cranlogs.r-pkg.org/badges/upstartr)](https://cranlogs.r-pkg.org/badges/upstartr)
<!-- badges: end -->
<p align="center">
  <img src="https://raw.githubusercontent.com/globeandmail/upstartr/master/images/upstartr-sticker.png" alt="upstartr logo" width="40%" height="40%" />
</p>

Upstartr is a companion package to The Globe and Mail's data journalism template, [**startr**](https://github.com/globeandmail/startr). It contains a series of functions meant to be consumed by the template project, plus additional helpful functions for day-to-day data journalism.

### Installation

```r
install.packages('upstartr')
```

Or, if you want to run a development version, you can install it from GitHub by doing:
```r
devtools::install_github('globeandmail/upstartr')
library(upstartr)
```

### Reference

You can find the full reference manual for `upstartr`'s functions [**here**](https://globeandmail.github.io/upstartr/).

### Credits

Spark plug illustration by Murat Yükselir.

### Get in touch

If you've got any questions, feel free to send us an email, or give us a shout on Twitter:

[![Tom Cardoso](https://avatars0.githubusercontent.com/u/2408118?v=3&s=65)](https://github.com/tomcardoso)
---
[Tom Cardoso](mailto:tcardoso@globeandmail.com) <br> [@tom_cardoso](https://twitter.com/tom_cardoso)
